/**
 * Translates variables provided by https://www.npmjs.com/package/wikimedia-ui-base
 * to SCSS and stores it alongside this package for use in our styles
 */
const fs = require( 'fs' );

let gonzales, lessVariableResolver, sast;
try {
	gonzales = require( 'gonzales-pe' );
	lessVariableResolver = require( 'less-variable-resolver' );
	sast = require( 'sast' );
} catch ( _ ) {
	// eslint-disable-next-line no-console
	console.warn(
		'Dev dependencies not found. ' +
			'If you are running `npm install --only=production` under npm v7+, ' +
			'this is expected because this script should not actually run: ' +
			'see <https://github.com/npm/cli/issues/4027>. ' +
			'Otherwise, something is wrong.',
	);
	return;
}

const WIKIMEDIA_UI_BASE_DIR = `${__dirname}/../node_modules/wikimedia-ui-base`;

const lessTree = gonzales.parse(
	fs.readFileSync( `${WIKIMEDIA_UI_BASE_DIR}/wikimedia-ui-base.less`, 'utf8' ),
	{ syntax: 'less' },
);

lessVariableResolver.log.level = process.argv.indexOf( '--debug' ) !== -1 ? 'debug' : 'warn';
lessVariableResolver.resolveVariablesInTree( lessTree );

const scssTree = sast.parse( lessTree.toString(), { syntax: 'less' } );

fs.writeFileSync(
	`${WIKIMEDIA_UI_BASE_DIR}/_wikimedia-ui-base.scss`,
	`// Autogenerated by termbox build process
// All variables are resolved - check the original less file to understand their relation
${sast.stringify( scssTree )}`,
);
